==> haskell-missingh-1.6.0.2-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MissingH
version:              1.6.0.2
visibility:           public
id:                   MissingH-1.6.0.2-7waGblV6MAOAc7VVZj3b1e
key:                  MissingH-1.6.0.2-7waGblV6MAOAc7VVZj3b1e
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  b2d7774c1dcb27c244a22ceaa0754de1
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.2-7waGblV6MAOAc7VVZj3b1e
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hslogger-1.3.2.0-HHnZePS3lQd6rnoeTbwVHs mtl-2.2.2
    network-3.1.4.0-4cEUA9pnnvEEvGlZk2FqT
    network-bsd-2.8.1.0-L5HEmsOfUJdFzoiASssZR1
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 parsec-3.1.16.1
    process-1.6.18.0 regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    time-1.12.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.6.0.2-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MissingH
version:              1.6.0.2
visibility:           public
id:                   MissingH-1.6.0.2-2UFWtmN8LWBFIrgZvNjQYL
key:                  MissingH-1.6.0.2-2UFWtmN8LWBFIrgZvNjQYL
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  e5e8b701c53c1af8d0ba2c04bec2a4e9
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MissingH-1.6.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.2-2UFWtmN8LWBFIrgZvNjQYL
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hslogger-1.3.2.0-1qY224WAgbRIf9sR8BuJiG mtl-2.2.2
    network-3.1.4.0-4UbSgXPdAp7DQ7Pftr1aPB
    network-bsd-2.8.1.0-AdZ7q19Usvj4P8px7xbjon
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 parsec-3.1.16.1
    process-1.6.18.0 regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    time-1.12.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
